[svn-commits] file: branch file/gulp_fax r394549 - /team/file/gulp_fax/res/res_sip_session.c

SVN commits to the Digium repositories svn-commits at lists.digium.com
Wed Jul 17 09:46:25 CDT 2013


Author: file
Date: Wed Jul 17 09:46:22 2013
New Revision: 394549

URL: http://svnview.digium.com/svn/asterisk?view=rev&rev=394549
Log:
When we get a 488 response to re-invite keep the session going.

Modified:
    team/file/gulp_fax/res/res_sip_session.c

Modified: team/file/gulp_fax/res/res_sip_session.c
URL: http://svnview.digium.com/svn/asterisk/team/file/gulp_fax/res/res_sip_session.c?view=diff&rev=394549&r1=394548&r2=394549
==============================================================================
--- team/file/gulp_fax/res/res_sip_session.c (original)
+++ team/file/gulp_fax/res/res_sip_session.c Wed Jul 17 09:46:22 2013
@@ -1835,8 +1835,8 @@
 				if (tsx->status_code == PJSIP_SC_REQUEST_PENDING) {
 					reschedule_reinvite(session, tsx->mod_data[session_module.id], tsx->last_tx);
 					return;
-				} else {
-					/* Other failures result in destroying the session. */
+				} else if (tsx->status_code != 488) {
+					/* Other failures (except 488) result in destroying the session. */
 					pjsip_tx_data *tdata;
 					pjsip_inv_end_session(inv, 500, NULL, &tdata);
 					ast_sip_session_send_request(session, tdata);




More information about the svn-commits mailing list